@@ -5,7 +5,7 @@ use Module::Install::Base;
 
 use vars qw{$VERSION $ISCORE @ISA};
 BEGIN {
-	$VERSION = '0.71';
+	$VERSION = '0.72';
 	$ISCORE  = 1;
 	@ISA     = qw{Module::Install::Base};
 }
@@ -270,7 +270,7 @@ sub name_from {
 	my $self = shift;
 	if (
 		Module::Install::_read($_[0]) =~ m/
-		^ \s
+		^ \s*
 		package \s*
 		([\w:]+)
 		\s* ;
@@ -367,4 +367,19 @@ sub license_from {
 	return 'unknown';
 }
 
+sub install_script {
+	my $self = shift;
+	my $args = $self->makemaker_args;
+	my $exe  = $args->{EXE_FILES} ||= [];
+        foreach ( @_ ) {
+		if ( -f $_ ) {
+			push @$exe, $_;
+		} elsif ( -d 'script' and -f "script/$_" ) {
+			push @$exe, "script/$_";
+		} else {
+			die "Cannot find script '$_'";
+		}
+	}
+}
+
 1;
